Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1409)

Unified Diff: mojo/public/cpp/application/application_delegate.h

Issue 1979723002: ApplicationConnection devolution, part 3. (Closed) Base URL: https://github.com/domokit/mojo.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « examples/trace_me/trace_me_app.cc ('k') | mojo/public/cpp/application/lib/application_delegate.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mojo/public/cpp/application/application_delegate.h
diff --git a/mojo/public/cpp/application/application_delegate.h b/mojo/public/cpp/application/application_delegate.h
index 4bf9cf28b962ec46ed2145b666a7e0b89d755ca5..6da1c4d6de9719670d3a8a80ae39503139d83396 100644
--- a/mojo/public/cpp/application/application_delegate.h
+++ b/mojo/public/cpp/application/application_delegate.h
@@ -7,6 +7,7 @@
#include <string>
+#include "mojo/public/cpp/application/service_provider_impl.h"
#include "mojo/public/cpp/system/macros.h"
namespace mojo {
@@ -25,9 +26,10 @@ class ApplicationDelegate {
virtual void Initialize(ApplicationImpl* app);
// Override this method to configure what services a connection supports when
- // being connected to from an app.
- // Return false to reject the connection entirely.
- virtual bool ConfigureIncomingConnection(ApplicationConnection* connection);
+ // being connected to from an app (|service_provider_impl| will never be
+ // null). Return false to reject the connection entirely.
+ virtual bool ConfigureIncomingConnection(
+ ServiceProviderImpl* service_provider_impl);
// Called before ApplicationImpl::Terminate(). After returning from this call
// the delegate can no longer rely on the main run loop still running.
« no previous file with comments | « examples/trace_me/trace_me_app.cc ('k') | mojo/public/cpp/application/lib/application_delegate.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698